upoints.utils.FileFormatError

Package upoints :: Module utils :: Class FileFormatError |
[hide private]
[frames] | no frames]

# Class FileFormatError

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
            exceptions.StandardError --+
                                       |
                   exceptions.ValueError --+
                                           |
                                          FileFormatError

Error object for data parsing error

    >>> raise FileFormatError
    Traceback (most recent call last):
        ...
    FileFormatError: Unsupported data format.
    >>> raise FileFormatError("test site")
    Traceback (most recent call last):
        ...
    FileFormatError: Incorrect data format, if you're using a file downloaded
    from test site please report this to James Rowe <jnrowe@ukfsn.org>

Since: 0.3.0

Instance Methods | [hide private]
__init__(self, site=None) Initialise a new FileFormatError object |
`str` |
__str__(self) Pretty printed error string |
Inherited from `exceptions.ValueError`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__` Inherited from `object`: `__hash__`, `__reduce_ex__`

Instance Variables | [hide private]
| site Remote site name to display in error message

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, site=None) (Constructor) |
Initialise a new FileFormatError object Parameters: `site` (`str`) - Remote site name to display in error message Overrides: object.__init__

### __str__(self) (Informal representation operator) |
Pretty printed error string Returns: `str` Human readable error string Overrides: object.__str__